@@ -1,10 +1,10 @@
 perm.bartlett.test <-
-function(formula,data,nperm=999) {
+function(formula,data,nperm=999,progress=TRUE) {
   if (missing(formula)||(length(formula)!=3)) {stop("missing or incorrect formula")}
   m <- match.call()
   if (is.matrix(eval(m$data,parent.frame()))) {m$data <- as.data.frame(m$data)}
   m[[1]] <- as.name("model.frame")
-  m$nperm <- NULL
+  m$nperm <- m$progress <- NULL
   mf <- eval(m,parent.frame())
   dname <- paste(paste(names(mf)[1],paste(names(mf)[2:ncol(mf)],collapse=":"),sep=" by "),"\n",nperm," permutations",sep="")
   resp <- mf[,1]
@@ -12,10 +12,10 @@ function(formula,data,nperm=999) {
   K.ref <- bartlett.test(resp~fact)$statistic
   K.perm <- numeric(nperm+1)
   K.perm[1] <- K.ref
-  pb <- txtProgressBar(min=0,max=100,initial=0,style=3)
+  if (progress) {pb <- txtProgressBar(min=0,max=100,initial=0,style=3)}
   for(i in 1:nperm) {
     K.perm[i+1] <- bartlett.test(sample(resp)~fact)$statistic
-    setTxtProgressBar(pb,round(i*100/nperm,0))
+    if (progress) {setTxtProgressBar(pb,round(i*100/nperm,0))}
   }
   cat("\n")
   pvalue <- length(which((K.perm+.Machine$double.eps/2) >= K.ref))/(nperm+1)
